@@ -63,7 +63,7 @@
 			$('#content').append($('footer'));
 
 			$('body').append('<div id="talk-sidebar" class="disappear"></div>');
-			$('#talk-sidebar').append('<div id="emptycontent"><div id="emptycontent-icon" class="icon-loading"></div><h2></h2><p></p></div>');
+			$('#talk-sidebar').append('<div id="emptycontent"><div id="emptycontent-icon" class="icon-loading"></div><h2></h2><p class="emptycontent-additional"></p></div>');
 			$('#talk-sidebar').append('<div id="call-container"></div>');
 			$('#call-container').append('<div id="videos"><div id="localVideoContainer" class="videoView videoContainer"></div></div>');
 			$('#call-container').append('<div id="screens"></div>');
@@ -74,27 +74,17 @@
 				'	<div class="avatar"></div>' +
 				'</div>' +
 				'<div class="nameIndicator">' +
-				'	<button id="mute" class="icon-audio icon-white icon-shadow" data-placement="top" data-toggle="tooltip" data-original-title="' + t('spreed', 'Mute audio (m)') + '"></button>' +
-				'	<button id="hideVideo" class="icon-video icon-white icon-shadow" data-placement="top" data-toggle="tooltip" data-original-title="' + t('spreed', 'Disable video (v)') + '"></button>' +
-				'	<button id="screensharing-button" class="app-navigation-entry-utils-menu-button icon-screen-off icon-white icon-shadow screensharing-disabled" data-placement="top" data-toggle="tooltip" data-original-title="' + t('spreed', 'Share screen') + '"></button>' +
-				'	<div id="screensharing-menu" class="app-navigation-entry-menu">' +
-				'		<ul>' +
-				'			<li>' +
-				'				<button id="show-screen-button">' +
-				'					<span class="icon-screen"></span>' +
-				'					<span>' + t('spreed', 'Show your screen') + '</span>' +
-				'				</button>' +
-				'			</li>' +
-				'			<li>' +
-				'				<button id="stop-screen-button">' +
-				'					<span class="icon-screen-off"></span>' +
-				'					<span>' + t('spreed', 'Stop screensharing') + '</span>' +
-				'				</button>' +
-				'			</li>' +
-				'		</ul>' +
-				'	</div>' +
 				'</div>');
 
+			OCA.SpreedMe.app.mainCallElementSelector = '#talk-sidebar';
+
+			OCA.SpreedMe.app._emptyContentView.destroy();
+			OCA.SpreedMe.app._emptyContentView = new OCA.SpreedMe.Views.EmptyContentView({
+				el: '#talk-sidebar > #emptycontent'
+			});
+
+			$('#localVideoContainer .nameIndicator').replaceWith(OCA.SpreedMe.app._mediaControlsView.$el);
+
 			OCA.SpreedMe.app.registerLocalVideoButtonHandlers();
 
 			$('body').addClass('talk-sidebar-enabled');
@@ -150,8 +140,7 @@
 					OCA.SpreedMe.app._chatView.$el.appendTo('#talk-sidebar');
 					OCA.SpreedMe.app._chatView.setTooltipContainer($('body'));
 
-					var participants = OCA.SpreedMe.app.activeRoom.get('participants');
-					OCA.SpreedMe.app.setRoomMessageForGuest(participants);
+					OCA.SpreedMe.app._emptyContentView.setActiveRoom(OCA.SpreedMe.app.activeRoom);
 
 					OCA.SpreedMe.app.setPageTitle(OCA.SpreedMe.app.activeRoom.get('displayName'));
 
