@@ -14,30 +14,15 @@ OC.L10N.register(
     "New group conversation" : "Νέα ομαδική συζήτηση",
     "{name} (public)" : "{name} (δημόσιο)",
     "New conversation …" : "Νέα συζήτηση …",
-    "Screensharing is not supported by your browser." : "Ο διαμοιρασμός της οθόνης δεν υποστηρίζεται από τον φυλλομετρητή σας.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η φόρτωση της σελίδας μέσω HTTPS.",
-    "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Η κοινή χρήση της οθόνης σας λειτουργεί μόνο με την έκδοση Firefox 52 ή νεότερη.",
-    "Screensharing extension is required to share your screen." : "Το πρόσθετο διαμοιρασμού οθόνης απαιτείται για να διαμοιράσετε την οθόνη σας.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Παρακαλώ χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή ο Chrome για να διαμοιάσετε την οθόνη σας.",
-    "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
     "Participants" : "Συμμετέχοντες",
     "Chat" : "Συνομιλία",
-    "Waiting for {participantName} to join the call …" : "Αναμονή για είσοδο στην κλήση του {participantName} ...",
-    "Waiting for others to join the call …" : "Αναμονή για είσοδο υπόλοιπων στην κλήση ...",
     "Exit fullscreen (f)" : "Έξοδος πλήρους οθόνης (f)",
     "Fullscreen (f)" : "Πλήρης οθόνη (f)",
-    "Mute audio (m)" : "Σίγαση ήχου (m)",
-    "Disable video (v)" : "Απενεργοποίηση βίντεο (v)",
-    "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
     "Copy" : "Αντιγραφή",
     "Copied!" : "Αντιγράφτηκε!",
     "Not supported!" : "Δεν υποστηρίζεται!",
     "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
     "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
-    "Share screen" : "Διαμοιρασμός οθόνης",
-    "Show your screen" : "Εμφάνιση της οθόνης σας",
-    "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
     "Password required" : "Απαιτείται συνθηματικό",
     "Password" : "Συνθηματικό",
     "Cancel" : "Ακύρωση",
@@ -55,20 +40,35 @@ OC.L10N.register(
     "Guest" : "Επισκέπτης",
     "Yesterday" : "Χθες",
     "Edit" : "Επεξεργασία",
-    "Add participant …" : "Προσθήκη συμμετέχοντα …",
     "No other people in this call" : "Κανένα άλλο άτομο σε αυτή την κλήση",
+    "Waiting for {participantName} to join the call …" : "Αναμονή για είσοδο στην κλήση του {participantName} ...",
+    "Waiting for others to join the call …" : "Αναμονή για είσοδο υπόλοιπων στην κλήση ...",
     "Share this link to invite others!" : "Διαμοιρασμός του συνδέσμου για να προσκαλέσετε άλλους!",
-    "Close" : "Κλείσιμο",
+    "WebRTC is not supported in your browser :-/" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας :-/",
+    "Please use a different browser like Firefox or Chrome" : "Παρακαλούμε χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή Chrome",
     "Waiting for camera and microphone permissions" : "Αναμονή για δικαιώματα για την κάμερα και το μικρόφωνο",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Παρακαλούμε δώστε πρόσβαση στον φυλλομετρητή να χρησιμοποιήσει την κάμερα και το μικρόφωνο ώστε να χρησιμοποιήσετε αυτή την εφαρμογή.",
     "Disable video" : "Απενεργοποίηση βίντεο",
+    "Share screen" : "Διαμοιρασμός οθόνης",
+    "Show your screen" : "Εμφάνιση της οθόνης σας",
+    "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
+    "Mute audio (m)" : "Σίγαση ήχου (m)",
+    "Disable video (v)" : "Απενεργοποίηση βίντεο (v)",
+    "Screensharing is not supported by your browser." : "Ο διαμοιρασμός της οθόνης δεν υποστηρίζεται από τον φυλλομετρητή σας.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η φόρτωση της σελίδας μέσω HTTPS.",
+    "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Η κοινή χρήση της οθόνης σας λειτουργεί μόνο με την έκδοση Firefox 52 ή νεότερη.",
+    "Screensharing extension is required to share your screen." : "Το πρόσθετο διαμοιρασμού οθόνης απαιτείται για να διαμοιράσετε την οθόνη σας.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Παρακαλώ χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή ο Chrome για να διαμοιάσετε την οθόνη σας.",
+    "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
+    "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
+    "Add participant …" : "Προσθήκη συμμετέχοντα …",
+    "Close" : "Κλείσιμο",
     "Show screen" : "Εμφάνιση οθόνης",
     "Access to microphone & camera is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο και στην κάμερα είναι εφικτή μόνο μέσω HTTPS",
     "Access to microphone & camera was denied" : "Άρνηση πρόσβασης στο μικρόφωνο & την κάμερα",
     "WebRTC is not supported in your browser" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας",
-    "Please use a different browser like Firefox or Chrome" : "Παρακαλούμε χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή Chrome",
     "Error while accessing microphone & camera" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο & την κάμερα",
-    "WebRTC is not supported in your browser :-/" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας :-/",
     "Guest's screen" : "Η οθόνη του επισκέπτη",
     "Your screen" : "Η οθόνη σας",
     "_%n guest_::_%n guests_" : ["%n επισκέπτης","%n επισκέπτες"],
@@ -79,30 +79,8 @@ OC.L10N.register(
     "TURN server" : "Διακομιστής TURN",
     "Android app" : "Εφαρμογή Android",
     "iOS app" : "Εφαρμογή iOS",
-    "Video calls" : "Κλήσεις βίντεο",
     "(group)" : "(ομάδα)",
-    "New public call" : "Νέα δημόσια κλήση",
-    "Looking great today! :)" : "Φαίνεσαι μια χαρά σήμερα! :)",
-    "Time to call your friends" : "Ώρα να καλέσετε τους φίλους σας",
-    "This call has ended" : "Αυτή η κλήση τερματίστηκε",
-    "Saving failed" : "Αποτυχία αποθήκευσης",
-    "Add person" : "Προσθήκη ατόμου",
     "and you" : "και εσείς",
-    "Please adjust your configuration" : "Παρακαλούμε προσαρμόστε τις ρυθμίσεις σας",
-    "You were invited to a <strong>video call</strong>" : "Έχετε προσκληθεί σε <strong>κλήση βίντεο</strong>",
-    "Video call" : "Κλήση βίντεο",
-    "Invalid format, must be stunserver:port." : "Μη έγκυρη μορφή, πρέπει να έχει τη μορφή stunserver:port.",
-    "Invalid port specified." : "Μη έγκυρος καθορισμός θύρας.",
-    "Invalid protocols specified." : "Μη έγκυρος καθορισμός πρωτοκόλλων.",
-    "%s invited you to a private call" : "Ο %s σας προσκάλεσε σε ιδιωτική κλήση",
-    "{user} invited you to a private call" : "Ο {user} σας προσκάλεσε σε ιδιωτική κλήση",
-    "%s invited you to a group call" : "Ο %s σας προσκάλεσε σε ομαδική κλήση",
-    "{user} invited you to a group call" : "Ο {user} σας προσκάλεσε σε ομαδική κλήση",
-    "Fullscreen" : "Πλήρης οθόνη",
-    "Mute audio" : "Σίγαση ήχου",
-    "Smile in 3… 2… 1!" : "Χαμογελάστε σε 3… 2… 1!",
-    "Choose person …" : "Επιλογή ατόμου ...",
-    "STUN server" : "Διακομιστής STUN",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …"
