@@ -17,39 +17,18 @@ OC.L10N.register(
     "New public conversation" : "דיון ציבורי חדש",
     "New group conversation" : "דיון קבוצתי חדש",
     "New conversation …" : "דיון חדש…",
-    "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
-    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
-    "Screensharing options" : "אפשרויות שיתוף מסך",
-    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
-    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
-    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
     "Participants" : "משתתפים",
     "Chat" : "צ׳אט",
     "Talk" : "שיחה",
-    "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
-    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
     "Fullscreen (f)" : "מסך מלא (f)",
-    "Mute audio (m)" : "השתקת שמע (m)",
-    "Unmute audio (m)" : "ביטול השקת שמע (m)",
-    "No audio" : "אין שמע",
-    "Disable video (v)" : "השבתת וידאו (v)",
-    "Enable video (v)" : "הפעלת וידאו (v)",
     "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
-    "No Camera" : "אין מצלמה",
-    "Enable screensharing" : "הפעלת שיתוף מסך",
     "Copy" : "העתקה",
     "Copied!" : "הועתק!",
     "Not supported!" : "אין תמיכה!",
     "Press ⌘-C to copy." : "להעתקה יש ללחוץ ‎⌘-C.",
     "Press Ctrl-C to copy." : "להעתקה יש ללחוץ Ctrl-C.",
-    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
-    "This conversation has ended" : "הדיון הסתיים",
     "Request password" : "בקשת ססמה",
-    "Share screen" : "שיתוף המסך",
-    "Show your screen" : "הצגת המסך שלך",
-    "Stop screensharing" : "הפסקת שיתוף המסך",
     "Error requesting the password." : "בקשת הססמה נכשלה.",
     "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
     "Password required" : "נדרשת ססמה",
@@ -80,6 +59,36 @@ OC.L10N.register(
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "אירעה שגיאה בעת שליחת ההודעה",
     "Edit" : "עריכה",
+    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
+    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
+    "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
+    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
+    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
+    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
+    "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
+    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
+    "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
+    "This conversation has ended" : "הדיון הסתיים",
+    "Disable video" : "השבתת וידאו",
+    "Share screen" : "שיתוף המסך",
+    "Show your screen" : "הצגת המסך שלך",
+    "Stop screensharing" : "הפסקת שיתוף המסך",
+    "Unmute audio (m)" : "ביטול השקת שמע (m)",
+    "Mute audio (m)" : "השתקת שמע (m)",
+    "No audio" : "אין שמע",
+    "Enable video (v)" : "הפעלת וידאו (v)",
+    "Disable video (v)" : "השבתת וידאו (v)",
+    "No Camera" : "אין מצלמה",
+    "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
+    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
+    "Screensharing options" : "אפשרויות שיתוף מסך",
+    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
+    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
+    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
+    "Enable screensharing" : "הפעלת שיתוף מסך",
     "moderator" : "מפקח/ת",
     "Demote from moderator" : "הורדה מדרגת פיקוח",
     "Promote to moderator" : "קידום לדרגת פיקוח",
@@ -90,23 +99,14 @@ OC.L10N.register(
     "Add to favorites" : "הוספה למועדפים",
     "Leave conversation" : "יציאה מהדיון",
     "Delete conversation" : "מחיקת דיון",
-    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
-    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
-    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
     "Close" : "סגירה",
-    "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
-    "Disable video" : "השבתת וידאו",
     "Show screen" : "הצגת מסך",
     "Enable video" : "הפעלת וידאו",
     "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
     "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
     "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
     "WebRTC is not supported in your browser" : "בדפדפן שלך אין תמיכה ב־WebRTC",
-    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
     "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
-    "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
     "{participantName}'s screen" : "המסך של {participantName}",
     "Guest's screen" : "המסך של האורח/ת",
     "Your screen" : "המסך שלך",
@@ -142,38 +142,8 @@ OC.L10N.register(
     "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר.",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "Video calls" : "שיחות וידאו",
     "(group)" : "(קבוצה)",
-    "New public call" : "שיחה ציבורית חדשה",
-    "Looking great today! :)" : "ואו! פשוט יפה! :)",
-    "Time to call your friends" : "הגיע הזמן להתקשר לחבריך",
-    "You can set your name on the top right of this page so other participants can identify you better." : "באפשרותך להגדיר את השם שלך בפינה השמאלית העליונה של העמוד הזה כדי שמשתתפים אחרים יוכלו לזהות אותך ביתר קלות.",
-    "This call has ended" : "השיחה הזאת הסתיימה",
-    "Saving failed" : "השמירה נכשלה",
-    "Add person" : "הוספת מישהו",
     "and you" : "ואני",
-    "Please adjust your configuration" : "נא להתאים את ההגדרות שלך",
-    "{actor} invited you to a private call" : "הוזמנת לשיחה פרטית על ידי {actor}",
-    "{actor} invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי {actor}",
-    "{actor} invited you to the call {call}" : "הוזמנת לשיחה {actor} על ידי {call}",
-    "You were invited to a <strong>video call</strong>" : "קיבלת הזמנה ל<strong>שיחת וידאו</strong>",
-    "Video call" : "שיחת וידאו",
-    "Invalid format, must be stunserver:port." : "תבנית שגויה, חייבת להיות stunserver:port.",
-    "Invalid port specified." : "הפתחה שצוינה שגויה.",
-    "Invalid protocols specified." : "הפרוטוקולים שצוינו שגויים.",
-    "%s invited you to a private call" : "הוזמנת לשיחה פרטית על ידי %s",
-    "{user} invited you to a private call" : "הוזמנת לשיחה פרטית על ידי {user}",
-    "%s invited you to a group call: %s" : "הוזמנת לשיחה קבוצתית על ידי %s‏: %s",
-    "{user} invited you to a group call: {call}" : "הוזמנת לשיחה קבוצתית על ידי {user}:‏ {call}",
-    "%s invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי %s",
-    "{user} invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי {user}",
-    "Fullscreen" : "מסך מלא",
-    "Mute audio" : "השתקת שמע",
-    "Smile in 3… 2… 1!" : "לחייך בעוד 3… 2… 1!",
-    "Choose person …" : "בחירת משתתף …",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "שרת ה־STUN נחוץ כדי שמשתמשים יוכלו להתחבר לשיחות. שרת ה־TURN דואג שהחיבור יעבור גם דרך חומות אש.",
-    "STUN server" : "שרת STUN",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "שרת ה־STUN משמש לאיתור כתובות ה־IP הציבורית של משתתפים שנמצאים מאחורי נתב.",
     "Password request by %s" : "בקשת ססמה מאת %s",
     "{email} requested the password to access a share" : "התקבלה בקשה לססמת גישה לשיתוף על ידי {email}"
 },
