@@ -11,28 +11,14 @@ OC.L10N.register(
     "UDP only" : "UDP만",
     "TCP only" : "TCP만",
     "TURN server protocols" : "TURN 서버 프로토콜",
-    "Screensharing is not supported by your browser." : "웹 브라우저에서 화면 공유를 지원하지 않습니다.",
-    "Screensharing requires the page to be loaded through HTTPS." : "화면 공유를 사용하려면 HTTPS로 페이지를 불러 와야 합니다.",
-    "Screensharing options" : "화면 공유 옵션",
-    "Sharing your screen only works with Firefox version 52 or newer." : "화면 공유는 Firefox 버전 52 이상에서만 지원합니다.",
-    "Screensharing extension is required to share your screen." : "화면 공유를 위한 확장 기능이 필요합니다.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "화면 공유를 사용하려면 Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오.",
-    "An error occurred while starting screensharing." : "화면 공유를 시작하는 중 오류가 발생했습니다.",
     "Participants" : "참가자",
     "Chat" : "대화",
     "Talk" : "토크",
-    "Waiting for {participantName} to join the call …" : "{participantName} 님을 기다리는 중…",
-    "Waiting for others to join the call …" : "다른 사람을 기다리는 중 …",
-    "No Camera" : "카메라 없음",
-    "Enable screensharing" : "화면 공유 활성화",
     "Copy" : "복사",
     "Copied!" : "복사 성공!",
     "Not supported!" : "지원하지 않음!",
     "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
     "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
-    "Share screen" : "화면 공유",
-    "Show your screen" : "내 화면 보이기",
-    "Stop screensharing" : "화면 공유 중지",
     "Please enter the password for this call" : "이 통화의 암호를 입력하십시오",
     "Password required" : "암호가 필요함",
     "Password" : "암호",
@@ -58,24 +44,38 @@ OC.L10N.register(
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "메시지를 보내는 중 오류 발생",
     "Edit" : "편집",
+    "No other people in this call" : "이 통화에 다른 사람이 없음",
+    "Waiting for {participantName} to join the call …" : "{participantName} 님을 기다리는 중…",
+    "Waiting for others to join the call …" : "다른 사람을 기다리는 중 …",
+    "You can invite others in the participant tab of the sidebar" : "사이드바의 참가자 탭에서 다른 사람들을 초대할 수 있음",
+    "Share this link to invite others!" : "다른 사람을 초대하려면 링크를 공유하십시오!",
+    "WebRTC is not supported in your browser :-/" : "웹 브라우저에서 WebRTC를 지원하지 않습니다 :-/",
+    "Please use a different browser like Firefox or Chrome" : "Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오",
+    "Waiting for camera and microphone permissions" : "카메라와 마이크 권한을 기다리는 중",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "이 앱을 사용하려면 웹 브라우저에 카메라 및 마이크 사용 권한을 부여해야 합니다.",
+    "Disable video" : "비디오 비활성화",
+    "Share screen" : "화면 공유",
+    "Show your screen" : "내 화면 보이기",
+    "Stop screensharing" : "화면 공유 중지",
+    "No Camera" : "카메라 없음",
+    "Screensharing is not supported by your browser." : "웹 브라우저에서 화면 공유를 지원하지 않습니다.",
+    "Screensharing requires the page to be loaded through HTTPS." : "화면 공유를 사용하려면 HTTPS로 페이지를 불러 와야 합니다.",
+    "Screensharing options" : "화면 공유 옵션",
+    "Sharing your screen only works with Firefox version 52 or newer." : "화면 공유는 Firefox 버전 52 이상에서만 지원합니다.",
+    "Screensharing extension is required to share your screen." : "화면 공유를 위한 확장 기능이 필요합니다.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "화면 공유를 사용하려면 Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오.",
+    "An error occurred while starting screensharing." : "화면 공유를 시작하는 중 오류가 발생했습니다.",
+    "Enable screensharing" : "화면 공유 활성화",
     "moderator" : "중재자",
     "Demote from moderator" : "중재자 권한 박탈",
     "Promote to moderator" : "중재자 권한 부여",
     "Remove participant" : "참가자 삭제",
-    "No other people in this call" : "이 통화에 다른 사람이 없음",
-    "You can invite others in the participant tab of the sidebar" : "사이드바의 참가자 탭에서 다른 사람들을 초대할 수 있음",
-    "Share this link to invite others!" : "다른 사람을 초대하려면 링크를 공유하십시오!",
     "Close" : "닫기",
-    "Waiting for camera and microphone permissions" : "카메라와 마이크 권한을 기다리는 중",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "이 앱을 사용하려면 웹 브라우저에 카메라 및 마이크 사용 권한을 부여해야 합니다.",
-    "Disable video" : "비디오 비활성화",
     "Show screen" : "화면 보이기",
     "Access to microphone & camera is only possible with HTTPS" : "마이크와 카메라에는 HTTPS로만 접근할 수 있음",
     "Access to microphone & camera was denied" : "마이크 및 카메라 접근이 거부됨",
     "WebRTC is not supported in your browser" : "웹 브라우저에서 WebRTC를 지원하지 않음",
-    "Please use a different browser like Firefox or Chrome" : "Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오",
     "Error while accessing microphone & camera" : "마이크와 카메라에 접근하는 중 오류 발생",
-    "WebRTC is not supported in your browser :-/" : "웹 브라우저에서 WebRTC를 지원하지 않습니다 :-/",
     "{participantName}'s screen" : "{participantName} 님의 화면",
     "Guest's screen" : "손님의 화면",
     "Your screen" : "내 화면",
@@ -103,38 +103,8 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN 서버는 라우터 뒤에 있는 참가자의 공인 IP 주소를 판단하는 데 사용합니다.",
     "TURN server" : "TURN 서버",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN 서버는 방화벽 뒤에 있는 참가자의 트래픽을 중계합니다.",
-    "Video calls" : "영상 통화",
     "(group)" : "(그룹)",
-    "New public call" : "새 공개 통화",
-    "Looking great today! :)" : "오늘 괜찮아 보이시네요! :)",
-    "Time to call your friends" : "친구들에게 통화할 시간입니다",
-    "You can set your name on the top right of this page so other participants can identify you better." : "이 페이지 오른쪽 위에 이름을 입력하여 다른 참가자들과 구별할 수 있습니다.",
-    "This call has ended" : "통화가 끝남",
-    "Saving failed" : "저장 실패",
-    "Add person" : "사람 추가",
     "and you" : "그리고 나",
-    "Please adjust your configuration" : "설정을 조정하십시오",
-    "{actor} invited you to a private call" : "{actor} 님이 개인 통화에 초대함",
-    "{actor} invited you to a group call" : "{actor} 님이 그룹 통화에 초대함",
-    "{actor} invited you to the call {call}" : "{actor} 님이 통화 {call}에 초대함",
-    "You were invited to a <strong>video call</strong>" : "<strong>영상 통화</strong>에 초대받음",
-    "Video call" : "영상 통화",
-    "Invalid format, must be stunserver:port." : "형식이 잘못됨, stunserver:port 형식이어야 합니다.",
-    "Invalid port specified." : "포트가 잘못되었습니다.",
-    "Invalid protocols specified." : "프로토콜이 잘못되었습니다.",
-    "%s invited you to a private call" : "%s 님이 개인 통화에 초대함",
-    "{user} invited you to a private call" : "{user} 님이 개인 통화에 초대함",
-    "%s invited you to a group call: %s" : "%s 님이 그룹 통화에 초대함: %s",
-    "{user} invited you to a group call: {call}" : "{user} 님이 그룹 통화에 초대함: {call}",
-    "%s invited you to a group call" : "%s 님이 그룹 통화에 초대함",
-    "{user} invited you to a group call" : "{user} 님이 그룹 통화에 초대함",
-    "Fullscreen" : "전체 화면",
-    "Mute audio" : "오디오 음소거",
-    "Smile in 3… 2… 1!" : "3… 2… 1… 스마일!",
-    "Choose person …" : "사람 선택 …",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "참가자가 통화에 연결하려면 STUN 서버를 설정해야 합니다. TURN 서버는 방화벽 뒤에 있는 사람도 연결할 수 있도록 합니다.",
-    "STUN server" : "STUN 서버",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN 서버는 라우터 뒤에 있는 참가자의 공인 IP 주소를 판단하는 데 사용합니다.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …"
