@@ -14,39 +14,19 @@ OC.L10N.register(
     "New public conversation" : "Nowa publiczna rozmowa",
     "New group conversation" : "Nowa rozmowa grupowa",
     "New conversation …" : "Nowa rozmowa ...",
-    "Screensharing is not supported by your browser." : "Współdzielenie ekranu nie jest wspierane przez Twoją przeglądarkę.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Współdzielenie ekrany wymaga, aby strona została załadowana przez HTTPS.",
-    "Screensharing options" : "Opcje współdzielenia ekranu",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Współdzielenie twojego ekranu działa tylko z Firefoksem w wersji 52 lub nowszym.",
-    "Screensharing extension is required to share your screen." : "Aby współdzielić ekran wymagane jest rozszerzenie do współdzeielenia ekranu",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Aby współdzielić ekran proszę użyć innej przeglądarki jak Firefox lub Chrome.",
-    "An error occurred while starting screensharing." : "Wystąpił błąd podczas rozpoczynania współdzielenia ekranu.",
     "Participants" : "Uczestnicy",
     "Chat" : "Czat",
     "Talk" : "Rozmowa",
-    "Waiting for {participantName} to join the call …" : "Oczekiwanie na {participantName} by przyłączyć się do rozmowy…",
-    "Waiting for others to join the call …" : "Czekamy na innych aby przyłączyć się do rozmowy…",
     "Exit fullscreen (f)" : "Wyjdź z trybu pełnoekranowego (f)",
     "Fullscreen (f)" : "Tryb pełnoekranowy (f)",
-    "Mute audio (m)" : "Wycisz dźwięk (m)",
-    "Unmute audio (m)" : "Wyłącz wyciszenie dźwięku (m)",
-    "No audio" : "Brak dźwięku",
-    "Disable video (v)" : "Wyłącz wideo (v)",
-    "Enable video (v)" : "Włącz wideo (v)",
     "Set your name in the chat window so other participants can identify you better." : "Ustaw swoje imię w oknie czatu, aby inni mogli Cię zidentyfikować.",
-    "No Camera" : "Brak kamery",
-    "Enable screensharing" : "Włącz współdzielenie ekranu",
     "Copy" : "Kopiuj",
     "Copied!" : "Skopiowano!",
     "Not supported!" : "Brak wsparcia!",
     "Press ⌘-C to copy." : "Wciśnij ⌘-C by skopiować.",
     "Press Ctrl-C to copy." : "Wciśnij Ctrl-C by skopiować.",
-    "Join a conversation or start a new one" : "Dołącz do konwersacji lub rozpocznij nową",
-    "This conversation has ended" : "Konwersacja została zakończona",
+    "Share" : "Udostępnij",
     "Request password" : "Zażądaj hasła",
-    "Share screen" : "Współdziel ekran",
-    "Show your screen" : "Pokaż swój ekran",
-    "Stop screensharing" : "Zatrzymaj współdzielenie ekranu",
     "Error requesting the password." : "Błąd żądania hasła.",
     "Please enter the password for this call" : "Wprowadź hasło dla tej rozmowy",
     "Password required" : "Wymagane hasło",
@@ -70,7 +50,6 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Brak wiadomości, zacznij rozmowę!",
     "New message …" : "Nowa wiadomość…",
     "Send" : "Wyślij",
-    "Share" : "Udostępnij",
     "Guest" : "Gość",
     "[Unknown user name]" : "[Nieznana nazwa użytkownika]",
     "Today" : "Dzisiaj",
@@ -78,24 +57,45 @@ OC.L10N.register(
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "Podczas wysyłania wiadomości wystąpił błąd",
     "Edit" : "Edytuj",
+    "Join a conversation or start a new one" : "Dołącz do konwersacji lub rozpocznij nową",
+    "No other people in this call" : "W tej rozmowie nie uczestniczą inne osoby",
+    "Waiting for {participantName} to join the call …" : "Oczekiwanie na {participantName} by przyłączyć się do rozmowy…",
+    "Waiting for others to join the call …" : "Czekamy na innych aby przyłączyć się do rozmowy…",
+    "You can invite others in the participant tab of the sidebar" : "Można zaprosić inne osoby w zakładce Uczestnicy na pasku bocznym",
+    "Share this link to invite others!" : "Udostępniaj ten link aby zapraszać innych!",
+    "WebRTC is not supported in your browser :-/" : "WebRTC nie jest wspierana przez Twoją przeglądarkę :-/",
+    "Please use a different browser like Firefox or Chrome" : "Proszę użyć innej przeglądarki jak Firefox czy Chrome",
+    "Waiting for camera and microphone permissions" : "Czekam na zezwolenie uprawnień dla mikrofonu i kamery",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Proszę dać swojej przeglądarce uprawnienia do użycia kamery i mikrofonu, aby używać tej aplikacji",
+    "This conversation has ended" : "Konwersacja została zakończona",
+    "Disable video" : "Wyłącz wideo.",
+    "Share screen" : "Współdziel ekran",
+    "Show your screen" : "Pokaż swój ekran",
+    "Stop screensharing" : "Zatrzymaj współdzielenie ekranu",
+    "Unmute audio (m)" : "Wyłącz wyciszenie dźwięku (m)",
+    "Mute audio (m)" : "Wycisz dźwięk (m)",
+    "No audio" : "Brak dźwięku",
+    "Enable video (v)" : "Włącz wideo (v)",
+    "Disable video (v)" : "Wyłącz wideo (v)",
+    "No Camera" : "Brak kamery",
+    "Screensharing is not supported by your browser." : "Współdzielenie ekranu nie jest wspierane przez Twoją przeglądarkę.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Współdzielenie ekrany wymaga, aby strona została załadowana przez HTTPS.",
+    "Screensharing options" : "Opcje współdzielenia ekranu",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Współdzielenie twojego ekranu działa tylko z Firefoksem w wersji 52 lub nowszym.",
+    "Screensharing extension is required to share your screen." : "Aby współdzielić ekran wymagane jest rozszerzenie do współdzeielenia ekranu",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Aby współdzielić ekran proszę użyć innej przeglądarki jak Firefox lub Chrome.",
+    "An error occurred while starting screensharing." : "Wystąpił błąd podczas rozpoczynania współdzielenia ekranu.",
+    "Enable screensharing" : "Włącz współdzielenie ekranu",
     "moderator" : "moderator",
     "Demote from moderator" : "Degraduj z moderatora",
     "Promote to moderator" : "Promuj na moderatora",
     "Remove participant" : "Usuń uczestnika",
-    "No other people in this call" : "W tej rozmowie nie uczestniczą inne osoby",
-    "You can invite others in the participant tab of the sidebar" : "Można zaprosić inne osoby w zakładce Uczestnicy na pasku bocznym",
-    "Share this link to invite others!" : "Udostępniaj ten link aby zapraszać innych!",
     "Close" : "Zakończ",
-    "Waiting for camera and microphone permissions" : "Czekam na zezwolenie uprawnień dla mikrofonu i kamery",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Proszę dać swojej przeglądarce uprawnienia do użycia kamery i mikrofonu, aby używać tej aplikacji",
-    "Disable video" : "Wyłącz wideo.",
     "Show screen" : "Pokaż ekran",
     "Access to microphone & camera is only possible with HTTPS" : "Dostęp do mikrofonu i kamery możliwe jest tylko za pomocą protokołu HTTPS",
     "Access to microphone & camera was denied" : "Dostępu do mikrofonu i kamery został odrzucony",
     "WebRTC is not supported in your browser" : "WebRTC nie jest wspierana przez Twoją przeglądarkę.",
-    "Please use a different browser like Firefox or Chrome" : "Proszę użyć innej przeglądarki jak Firefox czy Chrome",
     "Error while accessing microphone & camera" : "Wystąpił błąd podczas dostępu do mikrofonu i kamery",
-    "WebRTC is not supported in your browser :-/" : "WebRTC nie jest wspierana przez Twoją przeglądarkę :-/",
     "{participantName}'s screen" : "Ekran {participantName}",
     "Guest's screen" : "Ekran gościa",
     "Your screen" : "Twój ekran",
@@ -123,38 +123,8 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "Serwer STUN jest wykorzystywany do określania publicznego adresu IP uczestników znajdujących się za routerem.",
     "TURN server" : "TURN serwer",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serwer TURN jest używany do przekazywania ruchu od uczestników za firewallem.",
-    "Video calls" : "Wideo rozmowy",
     "(group)" : "(grupa)",
-    "New public call" : "Nowa publiczna rozmowa",
-    "Looking great today! :)" : "Świetnie dzisiaj wyglądasz! :)",
-    "Time to call your friends" : "Czas zadzwonić do Twoich przyjaciół",
-    "You can set your name on the top right of this page so other participants can identify you better." : "Możesz ustawić swoje imię w prawym górnym rogu tej strony, tak aby inni uczestnicy mogli lepiej Cię poznać.",
-    "This call has ended" : "Zakończono rozmowę",
-    "Saving failed" : "Zapisywanie nie powiodło się",
-    "Add person" : "Dodaj osobę",
     "and you" : "i ty",
-    "Please adjust your configuration" : "Proszę ustawić konfigurację",
-    "{actor} invited you to a private call" : "{actor} zaprosił(a) cię na prywatną rozmowę",
-    "{actor} invited you to a group call" : "{actor} zaprosił(a) cię do rozmowy grupowej",
-    "{actor} invited you to the call {call}" : "{actor} zaprosił(a) cię do rozmowy {call}",
-    "You were invited to a <strong>video call</strong>" : "Otrzymano zaproszenie do <strong> rozmowy wideo</string>",
-    "Video call" : "Rozmowa wideo",
-    "Invalid format, must be stunserver:port." : "Nieprawidłowy format, musi być stunserver:port.",
-    "Invalid port specified." : "Podano nieprawidłowy port.",
-    "Invalid protocols specified." : "Podano nieprawidłowy protokół.",
-    "%s invited you to a private call" : "%s zaprosił(a) Cię do prywatnej rozmowy",
-    "{user} invited you to a private call" : "{user} zaprosił(a) Cię do prywatnej rozmowy",
-    "%s invited you to a group call: %s" : "%s zaprosił(a) cię do grupowej rozmowy: %s",
-    "{user} invited you to a group call: {call}" : "{user} zaprosił(a) cię do grupowej rozmowy: {call}",
-    "%s invited you to a group call" : "%s zaprosił(a) Cię do grupowej rozmowy",
-    "{user} invited you to a group call" : "{user} zaprosił(a) Cię do grupowej rozmowy",
-    "Fullscreen" : "Pełny ekran",
-    "Mute audio" : "Wyciszenie audio",
-    "Smile in 3… 2… 1!" : "Uśmiechnij się 3… 2… 1!",
-    "Choose person …" : "Wybierz osobę…",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "Serwer STUN jest niezbędny aby umożliwić uczestnikom połączenie się do rozmów. Serwer TURN zapewnia, że połączenie będzie działać niezależnie od ustawień zapór sieciowych.",
-    "STUN server" : "STUN serwer",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "Serwer STUN jest wykorzystywany do określania publicznego adresu IP uczestników znajdujących się za routerem.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …"
