@@ -19,39 +19,18 @@ OC.L10N.register(
     "New group conversation" : "Tạo nhóm đàm thoại mới",
     "{name} (public)" : "{name} (public)",
     "New conversation …" : "Đàm thoại mới...",
-    "Screensharing is not supported by your browser." : "Chia sẽ màn hình không được hỗ trợ bởi trình duyệt của bạn.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
-    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
-    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
-    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
     "Participants" : "Người tham gia",
     "Chat" : "Trò chuyện",
     "Talk" : "Trò chuyện",
-    "Waiting for {participantName} to join the call …" : "Đang chờ {participantName} tham gia cuộc gọi…",
-    "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
     "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
     "Fullscreen (f)" : "Toàn màn hình (f)",
-    "Mute audio (m)" : "Tắt âm thành (m)",
-    "Unmute audio (m)" : "Mở âm thanh (m)",
-    "No audio" : "Không có âm thanh",
-    "Disable video (v)" : "Tắt Video (v)",
-    "Enable video (v)" : "Bật Video (v)",
     "Set your name in the chat window so other participants can identify you better." : "Đặt tên của bạn trong cửa sổ trò chuyện để những người tham gia khác có thể xác định bạn tốt hơn.",
-    "No Camera" : "Không có Camera",
-    "Enable screensharing" : "Bật chia sẽ màn hình",
     "Copy" : "Sao chép",
     "Copied!" : "Đã sao chép!",
     "Not supported!" : "Không hỗ trợ!",
     "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
     "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
-    "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
-    "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
     "Request password" : "Yêu cầu mật khẩu",
-    "Share screen" : "Chia sẽ màn hình",
-    "Show your screen" : "Hiện màn hình của bạn",
-    "Stop screensharing" : "Ngừng chia sẽ màn hình",
     "Error requesting the password." : "Lỗi khi đang yêu cầu mật khẩu.",
     "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
     "Password required" : "Mật khẩu đã được yêu cầu",
@@ -84,6 +63,36 @@ OC.L10N.register(
     "File to share" : "Tệp để chia sẻ",
     "Error while sharing" : "Lỗi khi chia sẻ",
     "Edit" : "Chỉnh sửa",
+    "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
+    "No other people in this call" : "Không có người nào trong cuộc gọi này",
+    "Waiting for {participantName} to join the call …" : "Đang chờ {participantName} tham gia cuộc gọi…",
+    "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
+    "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
+    "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
+    "WebRTC is not supported in your browser :-/" : "WebRTC không được hỗ trợ trong trình duyệt của bạn :-/",
+    "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
+    "Waiting for camera and microphone permissions" : "Đang chờ cấp quyền đối với máy ảnh và micrô",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vui lòng cung cấp cho trình duyệt quyền truy cập của bạn để sử dụng máy ảnh và micrô của bạn để sử dụng ứng dụng này.",
+    "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
+    "Disable video" : "Tắt Video",
+    "Share screen" : "Chia sẽ màn hình",
+    "Show your screen" : "Hiện màn hình của bạn",
+    "Stop screensharing" : "Ngừng chia sẽ màn hình",
+    "Unmute audio (m)" : "Mở âm thanh (m)",
+    "Mute audio (m)" : "Tắt âm thành (m)",
+    "No audio" : "Không có âm thanh",
+    "Enable video (v)" : "Bật Video (v)",
+    "Disable video (v)" : "Tắt Video (v)",
+    "No Camera" : "Không có Camera",
+    "Screensharing is not supported by your browser." : "Chia sẽ màn hình không được hỗ trợ bởi trình duyệt của bạn.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
+    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
+    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
+    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
+    "Enable screensharing" : "Bật chia sẽ màn hình",
     "moderator" : "Người kiểm duyệt",
     "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
     "Promote to moderator" : "Giới thiệu người kiểm duyệt",
@@ -94,23 +103,14 @@ OC.L10N.register(
     "Add to favorites" : "Thêm vào ưa thích",
     "Leave conversation" : "Rời khỏi cuộc đàm thoại",
     "Delete conversation" : "Xóa đàm thoại",
-    "No other people in this call" : "Không có người nào trong cuộc gọi này",
-    "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
-    "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
     "Close" : "Đóng",
-    "Waiting for camera and microphone permissions" : "Đang chờ cấp quyền đối với máy ảnh và micrô",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vui lòng cung cấp cho trình duyệt quyền truy cập của bạn để sử dụng máy ảnh và micrô của bạn để sử dụng ứng dụng này.",
-    "Disable video" : "Tắt Video",
     "Show screen" : "Hiện màn hình",
     "Enable video" : "Bật Video",
     "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
     "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
     "Access to microphone & camera was denied" : "Quyền truy cập vào micrô và máy ảnh đã bị từ chối",
     "WebRTC is not supported in your browser" : "WebRTC không được hỗ trợ trong trình duyệt của bạn",
-    "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
     "Error while accessing microphone & camera" : "Lỗi khi truy cập micrô và máy ảnh",
-    "WebRTC is not supported in your browser :-/" : "WebRTC không được hỗ trợ trong trình duyệt của bạn :-/",
     "{participantName}'s screen" : "Màn hình của {participantName}",
     "Guest's screen" : "Màn hình Khách",
     "Your screen" : "Màn hình của bạn",
@@ -193,38 +193,8 @@ OC.L10N.register(
     "Join conversations at any time, any where, on any device." : "Tham gia cuộc trò chuyện bất kỳ lúc nào, ở bất kỳ đâu, trên mọi thiết bị.",
     "Android app" : "Ứng dụng Android",
     "iOS app" : "Ứng dụng IOS",
-    "Video calls" : "Cuộc gọi Video",
     "(group)" : "(nhóm)",
-    "New public call" : "Cuộc gọi công khai mới",
-    "Looking great today! :)" : "Ngày hôm nay thật tuyệt vời! :)",
-    "Time to call your friends" : "Đã đến lúc gọi bạn bè của bạn",
-    "You can set your name on the top right of this page so other participants can identify you better." : "Bạn có thể đặt tên của mình ở trên cùng bên phải của trang này để những người tham gia khác có thể xác định bạn tốt hơn.",
-    "This call has ended" : "Cuộc gọi này đã kết thúc",
-    "Saving failed" : "Lỗi khi lưu",
-    "Add person" : "Thêm người",
     "and you" : "và bạn",
-    "Please adjust your configuration" : "Vui lòng điều chỉnh cấu hình của bạn",
-    "{actor} invited you to a private call" : "{actor} đã mời bạn tham gia cuộc gọi riêng",
-    "{actor} invited you to a group call" : "{actor} đã mời bạn tham gia cuộc gọi nhóm",
-    "{actor} invited you to the call {call}" : "{actor} đã mời bạn tham gia cuộc gọi {call}",
-    "You were invited to a <strong>video call</strong>" : "Bạn đã được mời tham gia <strong>cuộc gọi điện video</strong>",
-    "Video call" : "Cuộc gọi Video",
-    "Invalid format, must be stunserver:port." : "Định dạng không hợp lệ, phải là stunserver:port.",
-    "Invalid port specified." : "Cổng chỉ định không hợp lệ.",
-    "Invalid protocols specified." : "Giao thức được chỉ định không hợp lệ.",
-    "%s invited you to a private call" : "%s đã mời bạn tham gia cuộc gọi riêng",
-    "{user} invited you to a private call" : "{user} đã mời bạn tham gia cuộc gọi riêng",
-    "%s invited you to a group call: %s" : "%sđã mời bạn tham gia cuộc gọi nhóm: %s ",
-    "{user} invited you to a group call: {call}" : "{user} đã mời bạn tham gia cuộc gọi nhóm: {call}",
-    "%s invited you to a group call" : "%sđã mời bạn tham gia cuộc gọi nhóm ",
-    "{user} invited you to a group call" : "{user} đã mời bạn tham gia cuộc gọi nhóm",
-    "Fullscreen" : "Đầy màn hình",
-    "Mute audio" : "Tắt âm thanh",
-    "Smile in 3… 2… 1!" : "Cười trong 3… 2… 1!",
-    "Choose person …" : "Chọn người…",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "Máy chủ STUN là cần thiết để người tham gia có thể kết nối với các cuộc gọi. Máy chủ TURN đảm bảo kết nối hoạt động ngay cả qua tường lửa.",
-    "STUN server" : "Máy chủ STUN",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của những người tham gia phía sau một bộ định tuyến.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s… ",
