@@ -23,11 +23,14 @@ namespace OCA\Spreed\Chat\SystemMessage;
 
 
 use OCA\Spreed\Chat\ChatManager;
+use OCA\Spreed\Chat\MessageParser;
+use OCA\Spreed\Chat\Parser\SystemMessage;
 use OCA\Spreed\Manager;
 use OCA\Spreed\Participant;
 use OCA\Spreed\Room;
 use OCA\Spreed\Share\RoomShareProvider;
 use OCA\Spreed\TalkSession;
+use OCP\Comments\IComment;
 use OCP\IUser;
 use OCP\IUserSession;
 use OCP\Share;
@@ -113,7 +116,7 @@ class Listener {
 			/** @var Room $room */
 			$room = $event->getSubject();
 			foreach ($participants as $participant) {
-				if ($userId !== $participant['userId']) {
+				if ($room->getObjectType() === 'file' || $userId !== $participant['userId']) {
 					$this->sendSystemMessage($room, 'user_added', ['user' => $participant['userId']]);
 				}
 			}
@@ -136,6 +139,18 @@ class Listener {
 				$this->sendSystemMessage($room, 'moderator_demoted', ['user' => $event->getArgument('user')]);
 			}
 		});
+		$this->dispatcher->addListener(Room::class . '::postSetParticipantTypeBySession', function(GenericEvent $event) {
+			/** @var Room $room */
+			$room = $event->getSubject();
+			/** @var Participant $participant */
+			$participant = $event->getArgument('participant');
+
+			if ($event->getArgument('newType') === Participant::GUEST_MODERATOR) {
+				$this->sendSystemMessage($room, 'guest_moderator_promoted', ['session' => sha1($participant->getSessionId())]);
+			} else if ($event->getArgument('newType') === Participant::GUEST) {
+				$this->sendSystemMessage($room, 'guest_moderator_demoted', ['session' => sha1($participant->getSessionId())]);
+			}
+		});
 		$listener = function(GenericEvent $event) {
 			/** @var IShare $share */
 			$share = $event->getSubject();
@@ -149,6 +164,41 @@ class Listener {
 		};
 		$this->dispatcher->addListener('OCP\Share::postShare', $listener);
 		$this->dispatcher->addListener(RoomShareProvider::class . '::' . 'share_file_again', $listener);
+
+		$this->dispatcher->addListener(MessageParser::class . '::parseMessage', function(GenericEvent $event) {
+			/** @var IComment $chatMessage */
+			$chatMessage = $event->getSubject();
+
+			if ($chatMessage->getVerb() !== 'system') {
+				return;
+			}
+
+			/** @var SystemMessage $parser */
+			$parser = \OC::$server->query(SystemMessage::class);
+
+			$user = $event->getArgument('user');
+			if ($user instanceof IUser) {
+				$parser->setUserInfo($event->getArgument('l10n'), $event->getArgument('user'));
+			} else {
+				/** @var Room $room */
+				$room = $event->getArgument('room');
+				/** @var TalkSession $talkSession */
+				$talkSession = \OC::$server->query(TalkSession::class);
+				$parser->setGuestInfo($event->getArgument('l10n'), sha1($talkSession->getSessionForRoom($room->getToken())));
+			}
+
+			try {
+				list($message, $parameters) = $parser->parseMessage($chatMessage);
+
+				$event->setArguments([
+					'message' => $message,
+					'parameters' => $parameters,
+				]);
+				$event->stopPropagation();
+			} catch (\OutOfBoundsException $e) {
+				// Unknown message, ignore
+			}
+		});
 	}
 
 	protected function sendSystemMessage(Room $room, string $message, array $parameters = []) {
