@@ -23,8 +23,7 @@ declare(strict_types=1);
 namespace OCA\Spreed\Notification;
 
 
-use OCA\Spreed\Chat\RichMessageHelper;
-use OCA\Spreed\Chat\SystemMessage\Parser;
+use OCA\Spreed\Chat\MessageParser;
 use OCA\Spreed\Exceptions\RoomNotFoundException;
 use OCA\Spreed\Manager;
 use OCA\Spreed\Room;
@@ -38,6 +37,7 @@ use OCP\L10N\IFactory;
 use OCP\Notification\INotification;
 use OCP\Notification\INotifier;
 use OCP\RichObjectStrings\Definitions;
+use OCP\Share;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager as IShareManager;
 
@@ -61,11 +61,8 @@ class Notifier implements INotifier {
 	/** @var ICommentsManager */
 	protected $commentManager;
 
-	/** @var RichMessageHelper */
-	protected $richMessageHelper;
-
-	/** @var Parser */
-	protected $systemMessageParser;
+	/** @var MessageParser */
+	protected $messageParser;
 
 	/** @var Definitions */
 	protected $definitions;
@@ -76,8 +73,7 @@ class Notifier implements INotifier {
 								IShareManager $shareManager,
 								Manager $manager,
 								ICommentsManager $commentManager,
-								RichMessageHelper $richMessageHelper,
-								Parser $systemMessageParser,
+								MessageParser $messageParser,
 								Definitions $definitions) {
 		$this->lFactory = $lFactory;
 		$this->url = $url;
@@ -85,8 +81,7 @@ class Notifier implements INotifier {
 		$this->shareManager = $shareManager;
 		$this->manager = $manager;
 		$this->commentManager = $commentManager;
-		$this->richMessageHelper = $richMessageHelper;
-		$this->systemMessageParser = $systemMessageParser;
+		$this->messageParser = $messageParser;
 		$this->definitions = $definitions;
 	}
 
@@ -118,7 +113,7 @@ class Notifier implements INotifier {
 
 		$notification
 			->setIcon($this->url->getAbsoluteURL($this->url->imagePath('spreed', 'app-dark.svg')))
-			->setLink($this->url->linkToRouteAbsolute('spreed.Page.index') . '?token=' . $room->getToken());
+			->setLink($this->url->linkToRouteAbsolute('spreed.pagecontroller.showCall', ['token' => $room->getToken()]));
 
 		$subject = $notification->getSubject();
 		if ($subject === 'invitation') {
@@ -186,13 +181,8 @@ class Notifier implements INotifier {
 			throw new \InvalidArgumentException('Unknown comment');
 		}
 
-		if ($comment->getVerb() === 'system') {
-			$user = $this->userManager->get($notification->getUser());
-			$this->systemMessageParser->setUserInfo($user, $l);
-			list($richMessage, $richMessageParameters) = $this->systemMessageParser->parseMessage($comment);
-		} else {
-			list($richMessage, $richMessageParameters) = $this->richMessageHelper->getRichMessage($comment);
-		}
+		$recipient = $this->userManager->get($notification->getUser());
+		list($richMessage, $richMessageParameters) = $this->messageParser->parseMessage($room, $comment, $l, $recipient);
 
 		$placeholders = $replacements = [];
 		foreach ($richMessageParameters as $placeholder => $parameter) {
@@ -207,96 +197,68 @@ class Notifier implements INotifier {
 		$notification->setParsedMessage(str_replace($placeholders, $replacements, $richMessage));
 		$notification->setRichMessage($richMessage, $richMessageParameters);
 
+		$richSubjectParameters = [
+			'user' => $richSubjectUser,
+			'call' => $richSubjectCall,
+		];
+
 		if ($notification->getSubject() === 'chat') {
-			$notification
-				->setParsedSubject(str_replace('{user}', $user->getDisplayName(), $l->t('{user} sent you a private message')))
-				->setRichSubject(
-					$l->t('{user} sent you a private message'), [
-						'user' => $richSubjectUser,
-						'call' => $richSubjectCall,
-					]
-				);
-
-		} else if ($room->getType() === Room::ONE_TO_ONE_CALL) {
-			$notification
-				->setParsedSubject(
-					$l->t('%s mentioned you in a private conversation', [$user->getDisplayName()])
-				)
-				->setRichSubject(
-					$l->t('{user} mentioned you in a private conversation'), [
-						'user' => $richSubjectUser,
-						'call' => $richSubjectCall,
-					]
-				);
-
-		} else if (\in_array($room->getType(), [Room::GROUP_CALL, Room::PUBLIC_CALL], true)) {
-			if ($richSubjectUser && $room->getName() !== '') {
-				$notification
-					->setParsedSubject(
-						$l->t('%s mentioned you in a group conversation: %s', [$user->getDisplayName(), $room->getName()])
-					)
-					->setRichSubject(
-						$l->t('{user} mentioned you in a group conversation: {call}'), [
-							'user' => $richSubjectUser,
-							'call' => $richSubjectCall,
-						]
-					);
-			} else if ($richSubjectUser) {
-				$notification
-					->setParsedSubject(
-						$l->t('%s mentioned you in a group conversation', [$user->getDisplayName()])
-					)
-					->setRichSubject(
-						$l->t('{user} mentioned you in a group conversation'), [
-							'user' => $richSubjectUser,
-							'call' => $richSubjectCall,
-						]
-					);
-			} else if (!$isGuest && $room->getName() !== '') {
-				$notification
-					->setParsedSubject(
-						$l->t('You were mentioned in a group conversation by a deleted user: %s', [$room->getName()])
-					)
-					->setRichSubject(
-						$l->t('You were mentioned in a group conversation by a deleted user: {call}'), [
-							'call' => $richSubjectCall,
-						]
-					);
-			} else if (!$isGuest) {
-				$notification
-					->setParsedSubject(
-						$l->t('You were mentioned in a group conversation by a deleted user')
-					)
-					->setRichSubject(
-						$l->t('You were mentioned in a group conversation by a deleted user'), [
-							'call' => $richSubjectCall,
-						]
-					);
-			} else if ($room->getName() !== '') {
-				$notification
-					->setParsedSubject(
-						$l->t('A guest mentioned you in a group conversation: %s', [$room->getName()])
-					)
-					->setRichSubject(
-						$l->t('A guest mentioned you in a group conversation: {call}'), [
-							'call' => $richSubjectCall,
-						]
-					);
+			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+				$subject = $l->t('{user} sent you a private message');
 			} else {
-				$notification
-					->setParsedSubject(
-						$l->t('A guest mentioned you in a group conversation')
-					)
-					->setRichSubject(
-						$l->t('A guest mentioned you in a group conversation'), [
-							'call' => $richSubjectCall,
-						]
-					);
+				if ($richSubjectUser) {
+					if ($room->getName() !== '') {
+						$subject = $l->t('{user} sent a message in conversation {call}');
+					} else {
+						$subject = $l->t('{user} sent a message in a conversation');
+					}
+				} else if (!$isGuest) {
+					if ($room->getName() !== '') {
+						$subject = $l->t('A deleted user sent a message in conversation {call}');
+					} else {
+						$subject = $l->t('A deleted user sent a message in a conversation');
+					}
+				} else if ($room->getName() !== '') {
+					$subject = $l->t('A guest sent a message in conversation {call}');
+				} else {
+					$subject = $l->t('A guest sent a message in a conversation');
+				}
 			}
+		} else if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			$subject = $l->t('{user} mentioned you in a private conversation');
 		} else {
-			throw new \InvalidArgumentException('Unknown room type');
+			if ($richSubjectUser) {
+				if ($room->getName() !== '') {
+					$subject = $l->t('{user} mentioned you in conversation {call}');
+				} else {
+					$subject = $l->t('{user} mentioned you in a conversation');
+				}
+			} else if (!$isGuest) {
+				if ($room->getName() !== '') {
+					$subject = $l->t('A deleted user mentioned you in conversation {call}');
+				} else {
+					$subject = $l->t('A deleted user mentioned you in a conversation');
+				}
+			} else if ($room->getName() !== '') {
+				$subject = $l->t('A guest mentioned you in conversation {call}');
+			} else {
+				$subject = $l->t('A guest mentioned you in a conversation');
+			}
 		}
 
+		if ($richSubjectParameters['user'] === null) {
+			unset($richSubjectParameters['user']);
+		}
+
+		$placeholders = $replacements = [];
+		foreach ($richSubjectParameters as $placeholder => $parameter) {
+			$placeholders[] = '{' . $placeholder . '}';
+			$replacements[] = $parameter['name'];
+		}
+
+		$notification->setParsedSubject(str_replace($placeholders, $replacements, $subject))
+			->setRichSubject($subject, $richSubjectParameters);
+
 		return $notification;
 	}
 
@@ -502,19 +464,37 @@ class Notifier implements INotifier {
 			throw new \InvalidArgumentException('Unknown share');
 		}
 
-		$sharedWith = $share->getSharedWith();
+		try {
+			$file = [
+				'type' => 'highlight',
+				'id' => $share->getNodeId(),
+				'name' => $share->getNode()->getName(),
+			];
+		} catch (\OCP\Files\NotFoundException $e) {
+			throw new \InvalidArgumentException('Unknown file');
+		}
 
-		$notification
-			->setParsedSubject(str_replace('{email}', $sharedWith, $l->t('{email} requested the password to access a share')))
-			->setRichSubject(
-				$l->t('{email} requested the password to access a share'), [
-					'email' => [
-						'type' => 'email',
-						'id' => $sharedWith,
-						'name' => $sharedWith,
+		if ($share->getShareType() === Share::SHARE_TYPE_EMAIL) {
+			$sharedWith = $share->getSharedWith();
+
+			$notification
+				->setParsedSubject(str_replace(['{email}', '{file}'], [$sharedWith, $file['name']], $l->t('{email} requested the password to access {file}')))
+				->setRichSubject(
+					$l->t('{email} requested the password to access {file}'),
+					[
+						'email' => [
+							'type' => 'email',
+							'id' => $sharedWith,
+							'name' => $sharedWith,
+						],
+						'file' => $file,
 					]
-				]
-			);
+				);
+		} else {
+			$notification
+				->setParsedSubject(str_replace('{file}', $file['name'], $l->t('Someone requested the password to access {file}')))
+				->setRichSubject($l->t('Someone requested the password to access {file}'), ['file' => $file]);
+		}
 
 		return $notification;
 	}
