@@ -27,6 +27,7 @@ namespace OCA\Spreed;
 
 use OCA\Spreed\Exceptions\InvalidPasswordException;
 use OCA\Spreed\Exceptions\ParticipantNotFoundException;
+use OCA\Spreed\Exceptions\UnauthorizedException;
 use OCP\Comments\IComment;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
@@ -272,7 +273,7 @@ class Room {
 	}
 
 	public function deleteRoom() {
-		$participants = $this->getParticipants();
+		$participants = $this->getParticipantsLegacy();
 		$this->dispatcher->dispatch(self::class . '::preDeleteRoom', new GenericEvent($this, [
 			'participants' => $participants,
 		]));
@@ -526,12 +527,42 @@ class Room {
 		]));
 	}
 
+	/**
+	 * @param Participant $participant
+	 * @param int $participantType
+	 */
+	public function setParticipantTypeBySession(Participant $participant, int $participantType) {
+		$this->dispatcher->dispatch(self::class . '::preSetParticipantTypeBySession', new GenericEvent($this, [
+			'participant' => $participant,
+			'newType' => $participantType,
+		]));
+
+		$query = $this->db->getQueryBuilder();
+		$query->update('talk_participants')
+			->set('participant_type', $query->createNamedParameter($participantType, IQueryBuilder::PARAM_INT))
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->eq('session_id', $query->createNamedParameter($participant->getSessionId())));
+		$query->execute();
+
+		$this->dispatcher->dispatch(self::class . '::postSetParticipantTypeBySession', new GenericEvent($this, [
+			'participant' => $participant,
+			'newType' => $participantType,
+		]));
+	}
+
 	/**
 	 * @param IUser $user
 	 */
 	public function removeUser(IUser $user) {
+		try {
+			$participant = $this->getParticipant($user->getUID());
+		} catch (ParticipantNotFoundException $e) {
+			return;
+		}
+
 		$this->dispatcher->dispatch(self::class . '::preRemoveUser', new GenericEvent($this, [
 			'user' => $user,
+			'participant' => $participant,
 		]));
 
 		$query = $this->db->getQueryBuilder();
@@ -542,6 +573,7 @@ class Room {
 
 		$this->dispatcher->dispatch(self::class . '::postRemoveUser', new GenericEvent($this, [
 			'user' => $user,
+			'participant' => $participant,
 		]));
 	}
 
@@ -565,24 +597,31 @@ class Room {
 	}
 
 	/**
-	 * @param string $userId
+	 * @param IUser $user
 	 * @param string $password
 	 * @param bool $passedPasswordProtection
 	 * @return string
 	 * @throws InvalidPasswordException
+	 * @throws UnauthorizedException
 	 */
-	public function joinRoom($userId, $password, $passedPasswordProtection = false) {
-		$this->dispatcher->dispatch(self::class . '::preJoinRoom', new GenericEvent($this, [
-			'userId' => $userId,
+	public function joinRoom(IUser $user, $password, $passedPasswordProtection = false) {
+		$event = new GenericEvent($this, [
+			'userId' => $user->getUID(),
 			'password' => $password,
 			'passedPasswordProtection' => $passedPasswordProtection,
-		]));
+		]);
+		$this->dispatcher->dispatch(self::class . '::preJoinRoom', $event);
+
+		if ($event->hasArgument('cancel') && $event->getArgument('cancel') === true) {
+			$this->removeUser($user);
+			throw new UnauthorizedException('Participant is not allowed to join');
+		}
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_participants')
 			->set('session_id', $query->createParameter('session_id'))
 			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('user_id', $query->createNamedParameter($userId)));
+			->andWhere($query->expr()->eq('user_id', $query->createNamedParameter($user->getUID())));
 
 		$sessionId = $this->secureRandom->generate(255);
 		$query->setParameter('session_id', $sessionId);
@@ -595,7 +634,7 @@ class Room {
 
 			// User joining a public room, without being invited
 			$this->addUsers([
-				'userId' => $userId,
+				'userId' => $user->getUID(),
 				'participantType' => Participant::USER_SELF_JOINED,
 				'sessionId' => $sessionId,
 			]);
@@ -608,7 +647,7 @@ class Room {
 		}
 
 		$this->dispatcher->dispatch(self::class . '::postJoinRoom', new GenericEvent($this, [
-			'userId' => $userId,
+			'userId' => $user->getUID(),
 			'password' => $password,
 			'passedPasswordProtection' => $passedPasswordProtection,
 		]));
@@ -620,8 +659,15 @@ class Room {
 	 * @param string $userId
 	 */
 	public function leaveRoom($userId) {
+		try {
+			$participant = $this->getParticipant($userId);
+		} catch (ParticipantNotFoundException $e) {
+			return;
+		}
+
 		$this->dispatcher->dispatch(self::class . '::preUserDisconnectRoom', new GenericEvent($this, [
 			'userId' => $userId,
+			'participant' => $participant,
 		]));
 
 		// Reset session when leaving a normal room
@@ -644,6 +690,7 @@ class Room {
 
 		$this->dispatcher->dispatch(self::class . '::postUserDisconnectRoom', new GenericEvent($this, [
 			'userId' => $userId,
+			'participant' => $participant,
 			'selfJoin' => $selfJoined,
 		]));
 	}
@@ -653,9 +700,15 @@ class Room {
 	 * @param bool $passedPasswordProtection
 	 * @return string
 	 * @throws InvalidPasswordException
+	 * @throws UnauthorizedException
 	 */
 	public function joinRoomGuest($password, $passedPasswordProtection = false) {
-		$this->dispatcher->dispatch(self::class . '::preJoinRoomGuest', new GenericEvent($this));
+		$event = new GenericEvent($this);
+		$this->dispatcher->dispatch(self::class . '::preJoinRoomGuest', $event);
+
+		if ($event->hasArgument('cancel') && $event->getArgument('cancel') === true) {
+			throw new UnauthorizedException('Participant is not allowed to join');
+		}
 
 		if (!$passedPasswordProtection && !$this->verifyPassword($password)['result']) {
 			throw new InvalidPasswordException();
@@ -764,9 +817,35 @@ class Room {
 
 	/**
 	 * @param int $lastPing When the last ping is older than the given timestamp, the user is ignored
-	 * @return array[] Array of users with [users => [userId => [lastPing, sessionId]], guests => [[lastPing, sessionId]]]
+	 * @return Participant[]
 	 */
-	public function getParticipants($lastPing = 0) {
+	public function getParticipants($lastPing = 0): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('*')
+			->from('talk_participants')
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
+
+		if ($lastPing > 0) {
+			$query->andWhere($query->expr()->gt('last_ping', $query->createNamedParameter($lastPing, IQueryBuilder::PARAM_INT)));
+		}
+
+		$result = $query->execute();
+
+		$participants = [];
+		while ($row = $result->fetch()) {
+			$participants[] = $this->manager->createParticipantObject($this, $row);
+		}
+		$result->closeCursor();
+
+		return $participants;
+	}
+
+	/**
+	 * @param int $lastPing When the last ping is older than the given timestamp, the user is ignored
+	 * @return array[] Array of users with [users => [userId => [lastPing, sessionId]], guests => [[lastPing, sessionId]]]
+	 * @deprecated Use self::getParticipants() instead
+	 */
+	public function getParticipantsLegacy($lastPing = 0): array {
 		$query = $this->db->getQueryBuilder();
 		$query->select('*')
 			->from('talk_participants')
@@ -791,6 +870,7 @@ class Room {
 				$guests[] = [
 					'inCall' => (int) $row['in_call'],
 					'lastPing' => (int) $row['last_ping'],
+					'participantType' => (int) $row['participant_type'],
 					'sessionId' => $row['session_id'],
 				];
 			}
@@ -803,6 +883,53 @@ class Room {
 		];
 	}
 
+	/**
+	 * @param int $lastPing When the last ping is older than the given timestamp, the user is ignored
+	 * @return string[]
+	 */
+	public function getParticipantUserIds(int $lastPing = 0): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('user_id')
+			->from('talk_participants')
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->nonEmptyString('user_id'));
+
+		if ($lastPing > 0) {
+			$query->andWhere($query->expr()->gt('last_ping', $query->createNamedParameter($lastPing, IQueryBuilder::PARAM_INT)));
+		}
+
+		$result = $query->execute();
+
+		$users = [];
+		while ($row = $result->fetch()) {
+			$users[] = $row['user_id'];
+		}
+		$result->closeCursor();
+
+		return $users;
+	}
+
+	/**
+	 * @param int $notificationLevel
+	 * @return Participant[] Array of participants
+	 */
+	public function getParticipantsByNotificationLevel(int $notificationLevel): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('*')
+			->from('talk_participants')
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->eq('notification_level', $query->createNamedParameter($notificationLevel, IQueryBuilder::PARAM_INT)));
+		$result = $query->execute();
+
+		$participants = [];
+		while ($row = $result->fetch()) {
+			$participants[] = $this->manager->createParticipantObject($this, $row);
+		}
+		$result->closeCursor();
+
+		return $participants;
+	}
+
 	/**
 	 * @return string[]
 	 */
