@@ -611,11 +611,17 @@ class RoomShareProvider implements IShareProvider {
 	 */
 	public function getShareById($id, $recipientId = null) {
 		$qb = $this->dbConnection->getQueryBuilder();
-
-		$qb->select('*')
-			->from('share')
-			->where($qb->expr()->eq('id', $qb->createNamedParameter($id)))
-			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)));
+		$qb->select('s.*',
+			'f.fileid', 'f.path', 'f.permissions AS f_permissions', 'f.storage', 'f.path_hash',
+			'f.parent AS f_parent', 'f.name', 'f.mimetype', 'f.mimepart', 'f.size', 'f.mtime', 'f.storage_mtime',
+			'f.encrypted', 'f.unencrypted_size', 'f.etag', 'f.checksum'
+		)
+			->selectAlias('st.id', 'storage_string_id')
+			->from('share', 's')
+			->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
+			->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'))
+			->where($qb->expr()->eq('s.id', $qb->createNamedParameter($id)))
+			->andWhere($qb->expr()->eq('s.share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)));
 
 		$cursor = $qb->execute();
 		$data = $cursor->fetch();
@@ -625,6 +631,10 @@ class RoomShareProvider implements IShareProvider {
 			throw new ShareNotFound();
 		}
 
+		if (!$this->isAccessibleResult($data)) {
+			throw new ShareNotFound();
+		}
+
 		$share = $this->createShareObject($data);
 
 		if ($recipientId !== null) {
@@ -745,10 +755,16 @@ class RoomShareProvider implements IShareProvider {
 			}
 
 			$qb = $this->dbConnection->getQueryBuilder();
-			$qb->select('*')
-				->from('share')
+			$qb->select('s.*',
+				'f.fileid', 'f.path', 'f.permissions AS f_permissions', 'f.storage', 'f.path_hash',
+				'f.parent AS f_parent', 'f.name', 'f.mimetype', 'f.mimepart', 'f.size', 'f.mtime', 'f.storage_mtime',
+				'f.encrypted', 'f.unencrypted_size', 'f.etag', 'f.checksum'
+			)
+				->selectAlias('st.id', 'storage_string_id')
+				->from('share', 's')
 				->orderBy('id')
-				->setFirstResult(0);
+				->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
+				->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'));
 
 			if ($limit !== -1) {
 				$qb->setMaxResults($limit);
@@ -773,6 +789,10 @@ class RoomShareProvider implements IShareProvider {
 
 			$cursor = $qb->execute();
 			while ($data = $cursor->fetch()) {
+				if (!$this->isAccessibleResult($data)) {
+					continue;
+				}
+
 				if ($offset > 0) {
 					$offset--;
 					continue;
@@ -788,6 +808,22 @@ class RoomShareProvider implements IShareProvider {
 		return $shares;
 	}
 
+	private function isAccessibleResult($data) {
+		// exclude shares leading to deleted file entries
+		if ($data['fileid'] === null) {
+			return false;
+		}
+
+		// exclude shares leading to trashbin on home storages
+		$pathSections = explode('/', $data['path'], 2);
+		// FIXME: would not detect rare md5'd home storage case properly
+		if ($pathSections[0] !== 'files'
+			&& in_array(explode(':', $data['storage_string_id'], 2)[0], array('home', 'object'))) {
+			return false;
+		}
+		return true;
+	}
+
 	/**
 	 * Get a share by token
 	 *
@@ -902,14 +938,14 @@ class RoomShareProvider implements IShareProvider {
 					continue;
 				}
 
-				$userList = $room->getParticipants()['users'];
-				foreach ($userList as $uid => $participantData) {
-					$users[$uid] = isset($users[$uid]) ? $users[$uid] : [];
+				$userList = $room->getParticipantUserIds();
+				foreach ($userList as $uid) {
+					$users[$uid] = $users[$uid] ?? [];
 					$users[$uid][$row['id']] = $row;
 				}
 			} else if ($type === self::SHARE_TYPE_USERROOM && $currentAccess === true) {
 				$uid = $row['share_with'];
-				$users[$uid] = isset($users[$uid]) ? $users[$uid] : [];
+				$users[$uid] = $users[$uid] ?? [];
 				$users[$uid][$row['id']] = $row;
 			}
 		}
